Starting with Falcon 3.0, Python 2 is no longer supported. Therefore, support
for CPython 2.7 and PyPy2.7 was removed in this release. We will continue to
maintain the Falcon 2.x series for those who still need to run under Python 2,
at least until that platform's scheduled EOL (January 1, 2020 at the time of
this writing; see also PEP 373).
